* Implement electronic mechanisms to verify the identity of any person or entity requesting access to ePHI, before
  granting access to the ePHI.
* Use an appropriate authentication method to take reasonable steps to ensure that only properly authenticated workforce
  members access ePHI.
